---
title: xcollections
---

::: pyslurm.xcollections
    handler: python
    options:
        members:
            - MultiClusterMap
            - BaseView
            - KeysView
            - MCKeysView
            - ItemsView
            - MCItemsView
            - ValuesView
            - ClustersView
